<?php
defined('IN_WEB') or die('Include Error!');

/**
* 玩家反馈
*/
class Feedback
{
	public $param=[];
	function __construct($param)
	{
		$this->param = $param;
	}
    public function userAdd(){
        $ret = [];
        $data['type'] = funs::get('type');
        $data['user_id'] = funs::get('user_id');
        if(empty($data['user_id'])){
            $data['user_id'] = 1;
        }
        $data['content']= funs::get('content');
        $data['file']= !empty($this->param['file'])? $this->param['file']:'';
        $data['version'] =  funs::get('version');
		$data['sid']= funs::get('sid');
        $ret= oo::commonOprModel('feedback')->user_add($data);
        if(!empty($ret['error'])){
            $ret = oo::response($ret['error'],[],$ret['msg']);
        }
        $ret = oo::response(1,$ret['data'],$ret['msg']);
        return $ret;
    }
	public function userGet(){
        $ret = [];
        $uid = funs::get('user_id');
        if(empty($uid)){
            $uid = 1;
        }
        $ret= oo::commonOprModel('feedback')->user_get($uid);
        if(!empty($ret['error'])){
            $ret = oo::response($ret['error'],[],$ret['msg']);
        }
        $ret = oo::response(1,$ret['data'],$ret['msg']);
        return $ret;
    }

    public function userRead(){
        $ret = [];
        $uid = funs::get('user_id');
        if(empty($uid)){
            $uid = 1;
        }
        $ret= oo::commonOprModel('feedback')->user_read($uid);
        if(!empty($ret['error'])){
            $ret = oo::response($ret['error'],[],$ret['msg']);
        }
        $ret = oo::response(1,$ret['data'],$ret['msg']);
        return $ret;
    }
    public function sysGet(){
        $ret = [];
        $w = $this->param;
        $ret= oo::commonOprModel('feedback')->sys_get($w);
        if(!empty($ret['error'])){
            $ret = oo::response($ret['error'],[],$ret['msg']);
        }
//        $ret = oo::response(1,$ret['data'],$ret['msg']);
        $ret = json_encode($ret);
        return $ret;
    }
    public function sysRead(){
        $ret = [];
        $uid = funs::get('user_id');
        if(empty($uid)){
            return oo::response(-1,[],'userid not null');
        }
        $ret= oo::commonOprModel('feedback')->sys_read($uid);
        if(!empty($ret['error'])){
            $ret = oo::response($ret['error'],[],$ret['msg']);
        }
        $ret = oo::response(1,$ret['data'],$ret['msg']);
        return $ret;
    }
    public function sysAdd(){
        $ret = [];
        $uid = funs::get('user_id');
        if(empty($uid)||$uid==1){
            return oo::response(-1,[],'userid not null');
        }
        $ret= oo::commonOprModel('feedback')->sys_add($this->param);
        if(!empty($ret['error'])){
            $ret = oo::response($ret['error'],[],$ret['msg']);
        }
        $ret = oo::response(1,$ret['data'],$ret['msg']);
        return $ret;
    }


	/**
	*	反馈提交
	*/
	public function usersubmit($param)
	{
		$data = oo::commonOprModel('feedback')->usersubmit($param);
		return json_encode($data);
	}

}